summaryrefslogtreecommitdiff
path: root/src/formats/osxml/OsxmlEventParser.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/formats/osxml/OsxmlEventParser.hpp')
-rw-r--r--src/formats/osxml/OsxmlEventParser.hpp10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/formats/osxml/OsxmlEventParser.hpp b/src/formats/osxml/OsxmlEventParser.hpp
index 7a8c96d..4c5a485 100644
--- a/src/formats/osxml/OsxmlEventParser.hpp
+++ b/src/formats/osxml/OsxmlEventParser.hpp
@@ -96,10 +96,10 @@ public:
/**
* Called whenever string data is found.
*
* @param data is a Variant containing the string data that was found in the
* XML file.
*/
- virtual void data(const Variant &data) = 0;
+ virtual void data(const TokenizedData &data) = 0;
};
/**
@@ -179,7 +179,9 @@ public:
OsxmlEvents &getEvents() const;
/**
- * Returns a reference at the internal data.
+ * Used internally to fetch a reference at the internal data.
+ *
+ * @return a reference at the internal OsxmlEventParserData structure.
*/
OsxmlEventParserData &getData() const;
};
@@ -96,10 +96,10 @@ public:
* Called whenever string data is found.
*
- * @param data is a Variant containing the string data that was found in the
- * XML file.
+ * @param data is a TokenizedData instance containing the string data that
+ * was found in the XML file.
*/